@@ -1,6 +1,6 @@
 package Net::DNS::RR::MX;
 
-# $Id: MX.pm,v 1.2 2002/02/13 03:53:59 ctriv Exp $
+# $Id: MX.pm,v 1.3 2002/05/22 18:09:36 ctriv Exp $
 
 use strict;
 use vars qw(@ISA);
@@ -58,6 +58,19 @@ sub rr_rdata {
 	return $rdata;
 }
 
+sub _canonicalRdata {
+    my ($self) = @_;
+    my $rdata = "";
+    
+    if (exists $self->{"preference"}) {
+	$rdata .= pack("n", $self->{"preference"});
+	$rdata .= $self->_name2wire($self->{"exchange"})
+	}
+    
+    return $rdata;
+}
+
+
 1;
 __END__
 
