@@ -1,6 +1,6 @@
 package Net::DNS::RR::NAPTR;
 
-# $Id: NAPTR.pm,v 1.4 1997/07/06 16:31:54 mfuhr Exp $
+# $Id: NAPTR.pm,v 1.2 2002/02/13 03:53:59 ctriv Exp $
 
 use strict;
 use vars qw(@ISA);
@@ -163,9 +163,9 @@ Returns the replacement field.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997 Michael Fuhr.  All rights reserved.  This program is free
-software; you can redistribute it and/or modify it under the same terms as
-Perl itself. 
+Copyright (c) 1997-1998 Michael Fuhr.  All rights reserved.  This
+program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself. 
 
 B<Net::DNS::RR::NAPTR> is based on code contributed by Ryan Moats.
 
@@ -173,6 +173,6 @@ B<Net::DNS::RR::NAPTR> is based on code contributed by Ryan Moats.
 
 L<perl(1)>, L<Net::DNS>, L<Net::DNS::Resolver>, L<Net::DNS::Packet>,
 L<Net::DNS::Header>, L<Net::DNS::Question>, L<Net::DNS::RR>,
-draft-ietf-urn-naptr-I<xx>.txt
+RFC 2168
 
 =cut
